@@ -16,6 +16,7 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram-Dev.  If not, see <http://www.gnu.org/licenses/>.
 
+
 from .advanced import Advanced
 from .auth import Auth
 from .bots import Bots
@@ -25,7 +26,9 @@ from .decorators import Decorators
 from .invite_links import InviteLinks
 from .messages import Messages
 from .password import Password
+from .premium import Premium
 from .users import Users
+from .stories import Stories
 from .utilities import Utilities
 
 
@@ -35,8 +38,10 @@ class Methods(
     Bots,
     Contacts,
     Password,
+    Premium,
     Chats,
     Users,
+    Stories,
     Messages,
     Decorators,
     Utilities,
